@@ -4,8 +4,8 @@
 
 detect_rfkill eeepc-bluetooth
 BT_CTL="$RFKILL"
-[ -e $BT_CTL ] || BT_CTL=/sys/devices/platform/eeepc/bluetooth # pre-2.6.28
-[ -e $BT_CTL ] || BT_CTL=/proc/acpi/asus/bluetooth # pre-2.6.26
+[ -e "$BT_CTL" ] || BT_CTL=/sys/devices/platform/eeepc/bluetooth # pre-2.6.28
+[ -e "$BT_CTL" ] || BT_CTL=/proc/acpi/asus/bluetooth # pre-2.6.26
 # check if bluetooth is switched on and return success (exit code 0 if it is
 # return failure (exit code 1) if it is not
 #
@@ -13,7 +13,7 @@ BT_CTL="$RFKILL"
 # if not, uses hcitool to see if there is a hci0 device
 bluetooth_is_on()
 {
-    if [ -e $BT_CTL ]; then
+    if [ -e "$BT_CTL" ]; then
         [ $( cat $BT_CTL ) = "1" ]
     else
         if [ "$BLUETOOTH_FALLBACK_TO_HCITOOL" = "yes" ]; then
@@ -27,7 +27,7 @@ bluetooth_is_on()
 toggle_bluetooth()
 {
     if bluetooth_is_on; then
-        if [ -e $BT_CTL ]; then
+        if [ -e "$BT_CTL" ]; then
             echo 0 > $BT_CTL
             # udev should unload the module now
         elif [ "$BLUETOOTH_FALLBACK_TO_HCITOOL" = "yes" ]; then
@@ -40,7 +40,7 @@ toggle_bluetooth()
 	    done
         fi
     else
-        if [ -e $BT_CTL ]; then
+        if [ -e "$BT_CTL" ]; then
             echo 1 > $BT_CTL
             # udev should load the module now
         elif [ "$BLUETOOTH_FALLBACK_TO_HCITOOL" = "yes" ]; then
